==> generator-jquery-bootstrap-simple-1.0.1.tgz: package/README.md <==
# Simple jQuery & Bootstrap Yeoman generator with SASS
>This simple Yeoman generator gives you .html site organized with nice directory tree, ready to write/test your code snippets using jQuery and Bootstrap.
 
>You don't need to reaload page every time you change something because `grunt serverLive` task serves you efficient node sever with livereload (html/js/css) and it observes your .scss files with `compass watch` ! 

## Features
- live realoading of all .html .js .css files with node server - `grunt serverLive`
- minifying and concatenating .js and .css files - `grunt dist`
- write your CSS with SASS
- get benefits from: `Bower`, `Grunt` and `Copmass`

Autor: [Julian Sadowski](https://github.com/jsadowski)

## Installation

Firstly you must have installed `NodeJS` which comes with `NPM` installed (you can download it from its official site: [nodejs.org](https://nodejs.org/en/))

Secondly its good to update `npm` with command below:
```bash
sudo npm install npm -g
```
 
Then install `Yeoman`, `Bower` and `Grunt` npm packages typying:
```bash
 npm install -g yo bower grunt-cli
```
 
To write your `CSS` you will be using `SASS` so to compile it you need to get `Compass` framework. Type in your console:
```bash
gem update --system
gem install compass
```

Last thing you must do is install the generator:
```bash
npm install -g generator-jquery-bootstrap-simple
```

## How to use ?

Create an empty directory and enter it by:
```bash
mkdir mySite && cd mySite
```

Write command:
```bash
yo jquery-bootstrap-simple
```

... enter your project name in the console and ... that's it :) you can run command below to see your newly created page:
```bash
grunt serverLive
```

## Grunt tasks

Runs a node server (http://localhost:8000) with livereload (html/js/css)
```bash
grunt serverLive
```

Runs a node server (http://localhost:8000) witch `compass watch`
```bash
grunt server
```

Collects, concatenates, minificates and stores in public/dist directory .js and .css files with .min extension
```bash
grunt dist
```

Compiles css with `Compass`:
```bash
grunt compassCompile
```

## License

[BSD license](http://opensource.org/licenses/bsd-license.php)

==> generator-jquery-bootstrap-simple-1.0.2.tgz: package/README.md <==
# Simple jQuery & Bootstrap Yeoman generator with SASS
>This simple Yeoman generator gives you .html site organized with nice directory tree, ready to write/test your code snippets using jQuery and Bootstrap.
 
>You don't need to reaload page every time you change something because `grunt serverLive` task serves you efficient node sever with livereload (html/js/css) and it observes your .scss files with `compass watch` ! 

## Features
- live realoading of all .html .js .css files with node server - `grunt serverLive`
- minifying and concatenating .js and .css files - `grunt dist`
- write your CSS with SASS
- get benefits from: `Bower`, `Grunt` and `Copmass`

Autor: [Julian Sadowski](https://github.com/jsadowski)

## Installation

Firstly you must have installed `NodeJS` which comes with `NPM` installed (you can download it from its official site: [nodejs.org](https://nodejs.org/en/))

Secondly its good to update `npm` with command below:
```bash
sudo npm install npm -g
```
 
Then install `Yeoman`, `Bower` and `Grunt` npm packages typying:
```bash
 npm install -g yo bower grunt-cli
```
 
To write your `CSS` you will be using `SASS` so to compile it you need to get `Compass` framework. Type in your console:
```bash
gem update --system
gem install compass
```

Last thing you must do is install the generator:
```bash
npm install -g generator-jquery-bootstrap-simple
```

## How to use ?

Create an empty directory and enter it by:
```bash
mkdir mySite && cd mySite
```

Write command:
```bash
yo jquery-bootstrap-simple
```

... enter your project name in the console and ... that's it :) you can run command below to see your newly created page:
```bash
grunt serverLive
```

## Grunt tasks

Runs a node server (http://localhost:8000) with livereload (html/js/css) with `compass watch`
```bash
grunt serverLive
```

Runs a node server (http://localhost:8000) with `compass watch`
```bash
grunt server
```

Collects, concatenates, minificates and stores in public/dist directory .js and .css files with .min extension
```bash
grunt dist
```

Compiles css with `Compass`:
```bash
grunt compassCompile
```

## License

[BSD license](http://opensource.org/licenses/bsd-license.php)
